export type ElementPropsValue = string | number | boolean | undefined;
export type ElementProps = {
    [key: string]: ElementPropsValue;
};
export type RenderableElementFunction = (props: ElementProps, children: RenderableElement[]) => HtmlMethodResult;
export type ComplexRenderableElement<T extends string | RenderableElementFunction> = {
    type: T;
    props: ElementProps;
    children: RenderableElement[];
};
export type BasicRenderableElement = {
    type: string | RenderableElementFunction;
    props: ElementProps;
    children: RenderableElement[];
};
export type RenderableElement = string | number | ComplexRenderableElement<string | RenderableElementFunction>;
export type HtmlMethodResult = string | ComplexRenderableElement<string | RenderableElementFunction> | (string | ComplexRenderableElement<string | RenderableElementFunction>)[];
export type IterableIteratorMaybeAsync<T> = IterableIterator<T> | AsyncIterableIterator<T> | T[];
/**
 * @param {IterableIteratorMaybeAsync<string>} generator
 * @returns {Promise<string>}
 */
export function generatorToString(generator: IterableIteratorMaybeAsync<string>): Promise<string>;
/**
 * @param {TemplateStringsArray} strings
 * @param  {...ElementPropsValue|ElementProps|RenderableElementFunction|RenderableElement|RenderableElement[]} values
 * @returns {HtmlMethodResult}
 */
export function html(strings: TemplateStringsArray, ...values: (ElementPropsValue | ElementProps | RenderableElementFunction | RenderableElement | RenderableElement[])[]): HtmlMethodResult;
/**
 * @param {string|RenderableElementFunction} type
 * @param {ElementProps} props
 * @param  {...RenderableElement} children
 * @returns {BasicRenderableElement}
 */
export function h(type: string | RenderableElementFunction, props: ElementProps, ...children: RenderableElement[]): BasicRenderableElement;
/**
 * @param {HtmlMethodResult} item
 * @returns {AsyncIterableIterator<string>}
 */
export function render(item: HtmlMethodResult): AsyncIterableIterator<string>;
/**
 * @param {HtmlMethodResult} item
 * @returns {Promise<string>}
 */
export function renderToString(item: HtmlMethodResult): Promise<string>;
